<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class Jsrmsp_Plugin_Settings {

	/**
	 * The single instance of Jsrmsp_Plugin_Settings.
	 * @var 	object
	 * @access  private
	 * @since 	1.0.1
	 */
	private static $_instance = null;

	/**
	 * The main plugin object.
	 * @var 	object
	 * @access  public
	 * @since 	1.0.1
	 */
	public $parent = null;

	/**
	 * Prefix for plugin settings.
	 * @var     string
	 * @access  public
	 * @since   1.0.1
	 */
	public $base = '';

	/**
	 * Available settings for plugin.
	 * @var     array
	 * @access  public
	 * @since   1.0.1
	 */
	public $settings = array();

	public function __construct ( $parent ) {
		$this->parent = $parent;

		$this->base = 'jsrmsp_';

		// Initialise settings
		add_action( 'init', array( $this, 'init_settings' ), 11 );

		// Register plugin settings
		add_action( 'admin_init' , array( $this, 'register_settings' ) );

		// Add settings page to menu
		add_action( 'admin_menu' , array( $this, 'add_menu_item' ) );

		// Add settings link to plugins page
		add_filter( 'plugin_action_links_' . plugin_basename( $this->parent->file ) , array( $this, 'add_settings_link' ) );
	}

	/**
	 * Initialise settings
	 * @return void
	 */
	public function init_settings () {
		$this->settings = $this->settings_fields();
	}

	/**
	 * Add settings page to admin menu
	 * @return void
	 */
	public function add_menu_item () {
		/*$page = add_submenu_page( esc_html__( 'edit.php?post_type=jsrmsp_sr', 'jsrmsp-td' ) , esc_html__( 'Result Management Settings', 'jsrmsp-td' ) , 'Settings', 'manage_options' , $this->parent->_token . '_settings' ,  array( $this, 'settings_page' ) );
		add_action( 'admin_print_styles-' . $page, array( $this, 'settings_assets' ) );*/
		
		
		$page = add_options_page( esc_html__( 'Result Management Settings', 'jsrmsp-td' ) , esc_html__( 'Result Management Settings', 'jsrmsp-td' ) , 'manage_options' , $this->parent->_token . '_settings' ,  array( $this, 'settings_page' ) );
		add_action( 'admin_print_styles-' . $page, array( $this, 'settings_assets' ) );
	}

	/**
	 * Load settings JS & CSS
	 * @return void
	 */
	public function settings_assets () {

		// We're including the farbtastic script & styles here because they're needed for the colour picker
		// If you're not including a colour picker field then you can leave these calls out as well as the farbtastic dependency for the wpt-admin-js script below
		wp_enqueue_style( 'farbtastic' );
    	wp_enqueue_script( 'farbtastic' );

    	// We're including the WP media scripts here because they're needed for the image upload field
    	// If you're not including an image upload then you can leave this function call out
    	wp_enqueue_media();

    	wp_register_script( $this->parent->_token . '-settings-js', $this->parent->assets_url . 'js/settings' . $this->parent->script_suffix . '.js', array( 'farbtastic', 'jquery' ), '1.1.0' );
    	wp_enqueue_script( $this->parent->_token . '-settings-js' );
		

		// Localize the script with new data
		$jgcp_data_to_passed = array(
			'title'   => 'Hello world',
		);
		wp_localize_script( $this->parent->_token . '-settings-js', 'jgcpData', $jgcp_data_to_passed );
		
	}

	/**
	 * Add settings link to plugin list table
	 * @param  array $links Existing links
	 * @return array 		Modified links
	 */
	public function add_settings_link ( $links ) {
		$settings_link = '<a href="options-general.php?page=' . $this->parent->_token . '_settings">' . esc_html__( 'Settings', 'jsrmsp-td' ) . '</a>';
  		array_push( $links, $settings_link );
  		return $links;
	}

	/**
	 * Build settings fields
	 * @return array Fields to be displayed on settings page
	 */
	private function settings_fields () {

		$subjects = array();
		$totalSubjects = get_option('jsrmsp_total_subjects', true);

		array_push($subjects, array(
				'id' 			=> 'jsrmsp_subject_title',
				'label'			=> esc_html__( 'Subject group name' , 'jsrmsp-td' ),
				'description'	=> esc_html__( 'Change subject group name.', 'jsrmsp-td' ),
				'type'			=> 'text',
				'default'		=> 'All Subjects',
				'placeholder'	=> esc_html__( 'Change Subject Group Name', 'jsrmsp-td' )
			)
		);

		// Generate subjects
		for ($x = 1; $x <= $totalSubjects; $x++) {
			
			$singleSubject = array(
				'id' 			=> 'subject_'.$x,
				'label'			=> esc_html__( 'Subject '.$x , 'jsrmsp-td' ),
				'description'	=> esc_html__( 'Change subject name.', 'jsrmsp-td' ),
				'type'			=> 'text',
				'default'		=> 'Subject '.$x,
				'placeholder'	=> esc_html__( 'Subject Name', 'jsrmsp-td' )
			);

			array_push($subjects, $singleSubject);

		}

		// Generate required subject fields section
		$requiredSubjectsFields = array();

		for ($x = 1; $x <= $totalSubjects; $x++) {
			
			$singleSubject = array(
				'id' 			=> 'required_subject_f'.$x,
				'label'			=> get_option('jsrmsp_subject_'.$x),
				'description'	=> esc_html__( 'Check to required subject.', 'jsrmsp-td' ),
				'type'			=> 'checkbox',
				'default'		=> ''
			);

			array_push($requiredSubjectsFields, $singleSubject);

		}

		// Generate subjects hide show section
		$subjectsHideShow = array();

		array_push($subjectsHideShow,	
			array(
				'id' 			=> 'control_g1',
				'label'			=> get_option('jsrmsp_subject_title'),
				'description'	=> esc_html__( 'Check to hide full subejct group.', 'jsrmsp-td' ),
				'type'			=> 'checkbox',
				'default'		=> ''
			),
		);

		for ($x = 1; $x <= $totalSubjects; $x++) {
			
			$singleSubject = array(
				'id' 			=> 'control_subject_f'.$x,
				'label'			=> get_option('jsrmsp_subject_'.$x),
				'description'	=> esc_html__( 'Check to hide subject.', 'jsrmsp-td' ),
				'type'			=> 'checkbox',
				'default'		=> ''
			);

			array_push($subjectsHideShow, $singleSubject);

		}
		
		$settings['subjects'] = array(
			'title'					=> esc_html__( 'Total Subjects', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Change the total number of subjects.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'total_subjects',
					'label'			=> esc_html__( 'Total Subjects' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change total subjects.', 'jsrmsp-td' ),
					'type'			=> 'number',
					'default'		=> '100',
					'placeholder'	=> esc_html__( 'Change total subjects.', 'jsrmsp-td' )
				),
			)
		);

		$settings['info_fields'] = array(
			'title'					=> esc_html__( 'Fields', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Change info fields name as your choice.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'info_field_1',
					'label'			=> esc_html__( 'Father Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Father Name',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_2',
					'label'			=> esc_html__( 'Mother Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Mother Name',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_3',
					'label'			=> esc_html__( 'Student Type' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Student Type',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_4',
					'label'			=> esc_html__( 'Date OF Birth' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Date OF Birth',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_5',
					'label'			=> esc_html__( 'Gender' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Gender',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_6',
					'label'			=> esc_html__( 'Religion' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Religion',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_7',
					'label'			=> esc_html__( 'Roll No' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Roll No',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'info_field_8',
					'label'			=> esc_html__( 'Registration No' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change field name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Registration No',
					'placeholder'	=> esc_html__( 'Change field name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'gpa',
					'label'			=> esc_html__( 'GPA' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change gpa name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'GPA',
					'placeholder'	=> esc_html__( 'Grade Name', 'jsrmsp-td' )
				),
				
				array(
					'id' 			=> 'grade',
					'label'			=> esc_html__( 'Grade' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Grade name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Grade',
					'placeholder'	=> esc_html__( 'Grade Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'student_photo',
					'label'			=> esc_html__( 'Student\'s Photo' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Student\'s Photo.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Student\'s Photo',
					'placeholder'	=> esc_html__( 'Student\'s Photo', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'certificate',
					'label'			=> esc_html__( 'Upload Certificate' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change upload certificate text.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Upload Certificate',
					'placeholder'	=> esc_html__( 'Upload Certificate', 'jsrmsp-td' )
				)
			)
		);

		// Subjects fields
		$settings['subject_fields'] = array(
			'title'					=> esc_html__( 'Subjects', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Change subjects name as your choice.', 'jsrmsp-td' ),
			'fields'				=> $subjects
		);
		
		// Fields validation
		$settings['field_validation'] = array(
			'title'					=> esc_html__( 'Fields Validation', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Checked fields will be required', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'required_f1',
					'label'			=> get_option('jsrmsp_info_field_1'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f2',
					'label'			=> get_option('jsrmsp_info_field_2'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f3',
					'label'			=> get_option('jsrmsp_info_field_3'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f4',
					'label'			=> get_option('jsrmsp_info_field_4'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f5',
					'label'			=> get_option('jsrmsp_info_field_5'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f6',
					'label'			=> get_option('jsrmsp_info_field_6'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f7',
					'label'			=> get_option('jsrmsp_info_field_7'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f8',
					'label'			=> get_option('jsrmsp_info_field_8'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'required_f9',
					'label'			=> get_option('jsrmsp_gpa'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),

				array(
					'id' 			=> 'required_f11',
					'label'			=> get_option('jsrmsp_student_photo'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
			 
				array(
					'id' 			=> 'required_f10',
					'label'			=> get_option('jsrmsp_certificate'),
					'description'	=> esc_html__( 'Check to required field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
			)
		);

		// Subject validation
		$settings['subjects_validation'] = array(
			'title'					=> esc_html__( 'Subject Validation', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Checked subjects will be required.', 'jsrmsp-td' ),
			'fields'				=> $requiredSubjectsFields
		);
		
		/* Hide or show fields */
		
		$settings['field_control'] = array(
			'title'					=> esc_html__( 'Fields Hide/Show', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Checked fields will be hide', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'control_f1',
					'label'			=> get_option('jsrmsp_info_field_1'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f2',
					'label'			=> get_option('jsrmsp_info_field_2'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f3',
					'label'			=> get_option('jsrmsp_info_field_3'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f4',
					'label'			=> get_option('jsrmsp_info_field_4'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f5',
					'label'			=> get_option('jsrmsp_info_field_5'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f6',
					'label'			=> get_option('jsrmsp_info_field_6'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f7',
					'label'			=> get_option('jsrmsp_info_field_7'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),				
				
				
				array(
					'id' 			=> 'control_f8',
					'label'			=> get_option('jsrmsp_info_field_8'),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),		
				
				
				/* GPA and upload certificate group */
				
				array(
					'id' 			=> 'control_g2',
					'label'			=> get_option("jsrmsp_gpa").' and '.get_option("jsrmsp_certificate"),
					'description'	=> esc_html__( 'Check to hide full group.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				
				array(
					'id' 			=> 'control_f9',
					'label'			=> get_option("jsrmsp_gpa"),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				
				array(
					'id' 			=> 'control_f11',
					'label'			=> get_option("jsrmsp_student_photo"),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				
				array(
					'id' 			=> 'control_f10',
					'label'			=> get_option("jsrmsp_certificate"),
					'description'	=> esc_html__( 'Check to hide field.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
	
			)
		);

		// Subject hide show
		$settings['subject_fields_hide_show'] = array(
			'title'					=> esc_html__( 'Subjects Hide/Show', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Checked subject will be hide', 'jsrmsp-td' ),
			'fields'				=> $subjectsHideShow
		);
		
		// Edit Class year group section option
		
		$settings['cygs_page'] = array(
			'title'					=> esc_html__( 'Edit CYSG', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Change Class, Year, Group, Section\'s text according to your requirement.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'eclass',
					'label'			=> esc_html__( 'Class' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Class',
					'placeholder'	=> esc_html__( 'Class', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'eyear',
					'label'			=> esc_html__( 'Year' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Year',
					'placeholder'	=> esc_html__( 'Year', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'esection',
					'label'			=> esc_html__( 'Section' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Section',
					'placeholder'	=> esc_html__( 'Section', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'egroup',
					'label'			=> esc_html__( 'Group' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Group',
					'placeholder'	=> esc_html__( 'Group', 'jsrmsp-td' )
				)
				
			)
		);
		
		/* Page template option */
		
		$settings['page_template'] = array(
			'title'					=> esc_html__( 'Page Template', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'This settings for custom page template.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'bg_pattern',
					'label'			=> esc_html__( 'Background Pattern', 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Select a background pattern.', 'jsrmsp-td' ),
					'options'		=> array( '1' => 'Pattern 1', '2' => 'Pattern 2', '3' => 'Pattern 3', '4' => 'Pattern 4', '5' => 'Pattern 5', '6' => 'Pattern 6', '7' => 'Pattern 7' ),
					'type'			=> 'select',
					'default'		=> '1'
				),
				array(
					'id' 			=> 'color_scheme',
					'label'			=> esc_html__( 'Color Scheme', 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Select a Color Scheme.', 'jsrmsp-td' ),
					'type'			=> 'select',
					'options'		=> array( 'black' => 'Black', 'green' => 'Green', 'blue' => 'Blue', 'pink' => 'Pink' ),
					'default'		=> 'black'
				),
				array(
					'id' 			=> 'st_name',
					'label'			=> esc_html__( 'Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change name text.This changes will take effect in student name row in result output.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'school_name',
					'label'			=> esc_html__( 'Institute Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Add Institute name here.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Institute Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'page_favicon',
					'label'			=> esc_html__( 'Page Favicon' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Upload a favicon for custom page template.Image size should be 16x16 pixel with ico format.', 'jsrmsp-td' ),
					'type'			=> 'image',
					'default'		=> '',
					'placeholder'	=> ''
				),
				array(
					'id' 			=> 'page_logo',
					'label'			=> esc_html__( 'Page Logo' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Upload an image for custom page template.Image size should be 94x94 pixel with png format.', 'jsrmsp-td' ),
					'type'			=> 'image',
					'default'		=> '',
					'placeholder'	=> ''
				),
				array(
					'id' 			=> 'custom_page_title',
					'label'			=> esc_html__( 'Page Title' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Add page title here.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Page Title', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'custom_page_subtitle',
					'label'			=> esc_html__( 'Page SubTitle' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Add page subtitle here.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Page Subtitle', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'home_btn_link',
					'label'			=> esc_html__( 'Home button link' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change home button link here.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'http://example.com', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'resultPublication',
					'label'			=> esc_html__( 'Result publication' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change result header text.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Result Publication',
					'placeholder'	=> esc_html__( 'Result Publication', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'search_result_text',
					'label'			=> esc_html__( 'Search Result' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Search Result text. This change will take effect in shortcode based search form.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Search Result',
					'placeholder'	=> esc_html__( 'Search Result', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'resultHeader',
					'label'			=> esc_html__( 'Subject Wise Grade/Mark Sheet' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change subject header text.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Subject Wise Grade/Mark Sheet',
					'placeholder'	=> esc_html__( 'Subject Wise Grade/Mark Sheet', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'resultSubject',
					'label'			=> esc_html__( 'Subject' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change subject text. These change will take effect in subject header.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Subject',
					'placeholder'	=> esc_html__( 'Subject', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'grade',
					'label'			=> esc_html__( 'Grade' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Grade text. These change will take effect in Grade header.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Grade',
					'placeholder'	=> esc_html__( 'Grade Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'certificateRow',
					'label'			=> esc_html__( 'Certificate' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change certificate row text. These change will take effect in result output.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Certificate',
					'placeholder'	=> esc_html__( 'Certificate', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'result_failedNotice',
					'label'			=> esc_html__( 'Result Failed Notice' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'This notice will be displayed if no result found.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Result not found or not published yet',
					'placeholder'	=> esc_html__( 'Result not found or not published yet', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'result_notice',
					'label'			=> esc_html__( 'Result Notice' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'This notice will be displayed under result search form in custom page template.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Add result related notice here', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'resultPrintBtn',
					'label'			=> 'Display Result footer Button',
					'description'	=> esc_html__( 'Check to show Result Search Again and Print Button at the bottom of result.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'showQrcodeSignatureSection',
					'label'			=> 'Display the QR code and signature section.',
					'description'	=> esc_html__( 'Check to display QR Code and Signature section in the footer.', 'jsrmsp-td' ),
					'type'			=> 'checkbox',
					'default'		=> ''
				),
				array(
					'id' 			=> 'examControllerSignature',
					'label'			=> esc_html__( 'Exam Controller Signature' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Upload an image for Exam Controller.Image size should be 300x80 pixel with png format.', 'jsrmsp-td' ),
					'type'			=> 'image',
					'default'		=> '',
					'placeholder'	=> ''
				),
				array(
					'id' 			=> 'examControllerName',
					'label'			=> esc_html__( 'Exam Controller Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Exam Controller Name.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Enter Controller Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'controllerOfExam',
					'label'			=> esc_html__( 'Controller of Examination' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change Controller of Examination text.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> '',
					'placeholder'	=> esc_html__( 'Enter Controller of Examination text', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'watermarkImage',
					'label'			=> esc_html__( 'Watermark Image' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Upload an image for Watermark.Image size should be 500x500 pixel with png format.', 'jsrmsp-td' ),
					'type'			=> 'image',
					'default'		=> '',
					'placeholder'	=> ''
				),
				array(
					'id' 			=> 'footer_text',
					'label'			=> esc_html__( 'Footer Text' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'This text will be displayed at footer in custom page template.', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Ministry of Education, All rights reserved',
					'placeholder'	=> esc_html__( 'Ministry of Education, All rights reserved', 'jsrmsp-td' )
				)
			)
		);
		
		$settings['search_form'] = array(
			'title'					=> esc_html__( 'Search Form', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Edit & change search form according to your requirement.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'fullname',
					'label'			=> esc_html__( 'Full Name' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Full Name',
					'placeholder'	=> esc_html__( 'Full Name', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'birthdate',
					'label'			=> esc_html__( 'Birth Date' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Birth Date',
					'placeholder'	=> esc_html__( 'Birth Date', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'examination',
					'label'			=> esc_html__( 'Examination' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Examination',
					'placeholder'	=> esc_html__( 'Examination', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'year',
					'label'			=> esc_html__( 'Year' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Year',
					'placeholder'	=> esc_html__( 'Year', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'section',
					'label'			=> esc_html__( 'Section' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Section',
					'placeholder'	=> esc_html__( 'Section', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'group',
					'label'			=> esc_html__( 'Group' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Group',
					'placeholder'	=> esc_html__( 'Group', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'reg',
					'label'			=> esc_html__( 'Registration' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Registration',
					'placeholder'	=> esc_html__( 'Registration', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'roll',
					'label'			=> esc_html__( 'Roll' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Roll',
					'placeholder'	=> esc_html__( 'Roll', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 'searchBtn',
					'label'			=> esc_html__( 'Search Btn' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change search button text', 'jsrmsp-td' ),
					'type'			=> 'text',
					'default'		=> 'Search',
					'placeholder'	=> esc_html__( 'Search', 'jsrmsp-td' )
				),
				array(
					'id' 			=> 's_form_l',
					'label'			=> esc_html__( 'Change form', 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Choose a form.', 'jsrmsp-td' ),
					'options'		=> array( 
						'default'    => 'Form 1', 
						'roll'       => 'Form 2', 
						'all'        => 'Form 3', 
						'exrollnreg' => 'Form 4',
						'rollnreg'   => 'Form 5',
						'reg'        => 'Form 6',
						'namenbirth' => 'Form 7',
						'regnbirth' => 'Form 8'
					),
					'type'			=> 'select'
				)
			)
		);

		$settings['app_settings'] = array(
			'title'					=> esc_html__( 'App Settings', 'jsrmsp-td' ),
			'description'			=> esc_html__( 'Change App logo & others settings.', 'jsrmsp-td' ),
			'fields'				=> array(
				array(
					'id' 			=> 'app_logo',
					'label'			=> esc_html__( 'App Logo' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Upload an image for Mobile App.Image size should be 94x94 pixel with png format.', 'jsrmsp-td' ),
					'type'			=> 'image',
					'default'		=> '',
					'placeholder'	=> ''
				),
				array(
					'id' 			=> 'appNoticeText',
					'label'			=> esc_html__( 'App Notice' , 'jsrmsp-td' ),
					'description'	=> esc_html__( 'Change text', 'jsrmsp-td' ),
					'type'			=> 'textarea',
					'default'		=> 'Notice Text',
					'placeholder'	=> esc_html__( 'Notice Text', 'jsrmsp-td' )
				),
			)
		);

		$settings = apply_filters( $this->parent->_token . '_settings_fields', $settings );

		return $settings;
	}

	/**
	 * Register plugin settings
	 * @return void
	 */
	public function register_settings () {
		if ( is_array( $this->settings ) ) {

			// Check posted/selected tab
			$current_section = '';
			if ( isset( $_POST['tab'] ) && $_POST['tab'] ) {
				$current_section = $_POST['tab'];
			} else {
				if ( isset( $_GET['tab'] ) && $_GET['tab'] ) {
					$current_section = $_GET['tab'];
				}
			}

			foreach ( $this->settings as $section => $data ) {

				if ( $current_section && $current_section != $section ) continue;

				// Add section to page
				add_settings_section( $section, $data['title'], array( $this, 'settings_section' ), $this->parent->_token . '_settings' );

				foreach ( $data['fields'] as $field ) {

					// Validation callback for field
					$validation = '';
					if ( isset( $field['callback'] ) ) {
						$validation = $field['callback'];
					}

					// Register field
					$option_name = $this->base . $field['id'];
					register_setting( $this->parent->_token . '_settings', $option_name, $validation );

					// Add field to page
					add_settings_field( $field['id'], $field['label'], array( $this->parent->admin, 'display_field' ), $this->parent->_token . '_settings', $section, array( 'field' => $field, 'prefix' => $this->base ) );
				}

				if ( ! $current_section ) break;
			}
		}
	}

	public function settings_section ( $section ) {
		$html = '<p> ' . $this->settings[ $section['id'] ]['description'] . '</p>' . "\n";
		echo $html;
	}

	/**
	 * Load settings page content
	 * @return void
	 */
	public function settings_page () {

		// Build page HTML
		$html = '<div class="wrap" id="' . $this->parent->_token . '_settings">' . "\n";
			$html .= '<h2>' . esc_html__( 'Result Management Settings' , 'jsrmsp-td' ) . '</h2>' . "\n";

			$tab = '';
			if ( isset( $_GET['tab'] ) && $_GET['tab'] ) {
				$tab .= $_GET['tab'];
			}

			// Show page tabs
			if ( is_array( $this->settings ) && 1 < count( $this->settings ) ) {

				$html .= '<h2 class="nav-tab-wrapper">' . "\n";

				$c = 0;
				foreach ( $this->settings as $section => $data ) {

					// Set tab class
					$class = 'nav-tab';
					if ( ! isset( $_GET['tab'] ) ) {
						if ( 0 == $c ) {
							$class .= ' nav-tab-active';
						}
					} else {
						if ( isset( $_GET['tab'] ) && $section == $_GET['tab'] ) {
							$class .= ' nav-tab-active';
						}
					}

					// Set tab link
					$tab_link = add_query_arg( array( 'tab' => $section ) );
					if ( isset( $_GET['settings-updated'] ) ) {
						$tab_link = remove_query_arg( 'settings-updated', $tab_link );
					}

					// Output tab
					$html .= '<a href="' . $tab_link . '" class="' . esc_attr( $class ) . '">' . esc_html( $data['title'] ) . '</a>' . "\n";

					++$c;
				}

				$html .= '</h2>' . "\n";
			}

			$html .= '<form method="post" action="options.php" enctype="multipart/form-data">' . "\n";

				// Get settings fields
				ob_start();
				settings_fields( $this->parent->_token . '_settings' );
				do_settings_sections( $this->parent->_token . '_settings' );
				$html .= ob_get_clean();

				$html .= '<p class="submit">' . "\n";
					$html .= '<input type="hidden" name="tab" value="' . esc_attr( $tab ) . '" />' . "\n";
					$html .= '<input name="Submit" type="submit" class="button-primary" value="' . esc_attr( esc_html__( 'Save Settings' , 'jsrmsp-td' ) ) . '" />' . "\n";
				$html .= '</p>' . "\n";
			$html .= '</form>' . "\n";
		$html .= '</div>' . "\n";

		echo $html;
	}

	/**
	 * Main Jsrmsp_Plugin_Settings Instance
	 *
	 * Ensures only one instance of Jsrmsp_Plugin_Settings is loaded or can be loaded.
	 *
	 * @since 1.0.1
	 * @static
	 * @see Jsrmsp_Plugin_Template()
	 * @return Main Jsrmsp_Plugin_Settings instance
	 */
	public static function instance ( $parent ) {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self( $parent );
		}
		return self::$_instance;
	} // End instance()

	/**
	 * Cloning is forbidden.
	 *
	 * @since 1.0.1
	 */
	public function __clone () {
		_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?' ), $this->parent->_version );
	} // End __clone()

	/**
	 * Unserializing instances of this class is forbidden.
	 *
	 * @since 1.0.1
	 */
	public function __wakeup () {
		_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?' ), $this->parent->_version );
	} // End __wakeup()

}