<?php

/* Metaboxes */

add_filter( 'jsrmsp_meta_boxes', 'jsrmsp_student_informations' );
/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */
function jsrmsp_student_informations( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_jsrmsp_';

	$subjects = array();
	$totalSubjects = get_option('jsrmsp_total_subjects', true);

	// Generate subjects
	for ($x = 1; $x <= $totalSubjects; $x++) {
		
		$singleSubject = array(
			'name' => get_option('jsrmsp_subject_'.$x),
			'desc' => get_option('jsrmsp_subject_'.$x).' '.get_option('jsrmsp_grade'),
			'id'   => $prefix . 'subject_'.$x,
			'type' => 'text_medium',
		);

		array_push($subjects, $singleSubject);

	}


	/**
	 * Information
	 */
	$meta_boxes['student_information'] = array(
		'id'         => 'student_information',
		'title'      => 'Student\'s Information',
		'pages'      => array( 'jsrmsp_sr', ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		// 'cmb_styles' => true, // Enqueue the CMB stylesheet on the frontend
		'fields'     => array(
			
			array(
				'name' => get_option('jsrmsp_info_field_1'),
				'desc' => get_option('jsrmsp_info_field_1'),
				'id'   => $prefix . 'student_father_name',
				'type' => 'text_medium',
				// 'repeatable' => true,
			),
			
			array(
				'name' => get_option('jsrmsp_info_field_2'),
				'desc' => get_option('jsrmsp_info_field_2'),
				'id'   => $prefix . 'student_mother_name',
				'type' => 'text_medium',
				// 'repeatable' => true,
			),
			
			array(
				'name' => get_option('jsrmsp_info_field_3'),
				'desc' => get_option('jsrmsp_info_field_3'),
				'id'   => $prefix . 'student_type',
				'type'    => 'select',
				'options' => array(
					'' => 'Select',
					'Regular' => 'Regular',
					'Irregular'   => 'Irregular',
					'Corresponding'   => 'Corresponding',
					'Non-Corresponding'   => 'Non-Corresponding',
				),
				// 'repeatable' => true,
			),
			
			array(
				'name' => get_option('jsrmsp_info_field_4'),
				'desc' => get_option('jsrmsp_info_field_4').' Format (DD/MM/YEAR)',
				'id'   => $prefix . 'student_birth_date',
				'type' => 'text_date',
				// 'repeatable' => true,
			),
			
			array(
				'name'    => get_option('jsrmsp_info_field_5'),
				'desc'    => 'Select '.get_option('jsrmsp_info_field_5'),
				'id'      => $prefix . 'student_gender',
				'type'    => 'select',
				'options' => array(
					'' => 'Select',
					'Male' => 'Male',
					'Female'   => 'Female',
					'Other'   => 'Other',
				),
			),
			
			array(
				'name'    => get_option('jsrmsp_info_field_6'),
				'desc'    => get_option('jsrmsp_info_field_6'),
				'id'      => $prefix . 'student_religion',
				'type' => 'text_medium',
			),
			
			array(
				'name' => get_option('jsrmsp_info_field_7'),
				'desc' => get_option('jsrmsp_info_field_7'),
				'id'   => $prefix . 'student_roll',
				'type' => 'text_medium',
				// 'repeatable' => true,
			),
			
			array(
				'name' => get_option('jsrmsp_info_field_8'),
				'desc' => get_option('jsrmsp_info_field_8'),
				'id'   => $prefix . 'student_reg',
				'type' => 'text_medium',
				// 'repeatable' => true,
			),
			
		),
	);
	
	
	/**
	* Subjects
	*/

	$meta_boxes['subject_group_one'] = array(
		'id'         => 'subject_group',
		'title'      => get_option('jsrmsp_subject_title'),
		'pages'      => array( 'jsrmsp_sr', ), // Post type
		'context'    => 'normal',
		'priority'   => 'low',
		'show_names' => true, // Show field names on the left
		// 'cmb_styles' => true, // Enqueue the CMB stylesheet on the frontend
		'fields'     => $subjects,
	);

	//Total GPA
	
	$meta_boxes['student_photo'] = array(
		'id'         => 'student_photo',
		'title'      => get_option('jsrmsp_student_photo'),
		'pages'      => array( 'jsrmsp_sr', ), // Post type
		'context'    => 'side',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		// 'cmb_styles' => true, // Enqueue the CMB stylesheet on the frontend
		'fields'     => array(
			array(
				'name' => get_option('jsrmsp_student_photo'),
				'desc' => 'Upload or enter a URL for '.get_option('jsrmsp_student_photo').'. Preview available only for Image files. Image link should be direct link.',
				'id'   => $prefix . 'student_photo',
				'type' => 'file',
			),
			
		),
	);
	
	//Total GPA
	
	$meta_boxes['student_total_gpa'] = array(
		'id'         => 'student_total_gpa',
		'title'      => 'Student '.get_option('jsrmsp_gpa').' & Certificate',
		'pages'      => array( 'jsrmsp_sr', ), // Post type
		'context'    => 'side',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		// 'cmb_styles' => true, // Enqueue the CMB stylesheet on the frontend
		'fields'     => array(
			array(
				'name' => get_option('jsrmsp_gpa'),
				'desc' => get_option('jsrmsp_gpa'),
				'id'   => $prefix . 'total_gpa',
				'type' => 'text_medium',
				// 'repeatable' => true,
			),
			array(
				'name' => get_option('jsrmsp_certificate'),
				'desc' => 'Upload or enter a URL for Student\'s Certificate. Preview available only for Image files. Certificate link should be direct link.',
				'id'   => $prefix . 'certificate',
				'type' => 'file',
			),
			
		),
	);
	

	// Add other metaboxes as needed

	return $meta_boxes;
}

add_action( 'init', 'jsrmsp_student_info_initialize', 9999 );
/**
 * Initialize the metabox class.
 */
function jsrmsp_student_info_initialize() {

	if ( ! class_exists( 'jsrmsp_Meta_Box' ) )
		require_once 'init.php';

}
