<?php

/*-----------------------------------------------
 Add custom column to the post list table-----
------------------------------------------------*/

function jsrmsp_add_student_photo_column( $columns ) {
    $new_columns = array(
        'title' => 'Name',
        'jsrmsp_student_photo' => 'Photo',
    );
    return array_slice( $columns, 0, 1 ) + $new_columns + array_slice( $columns, 1 );
}
add_filter( 'manage_jsrmsp_sr_posts_columns', 'jsrmsp_add_student_photo_column' );

function jsrmsp_display_student_photo_column( $column_name, $post_id ) {
    if ( $column_name == 'jsrmsp_student_photo' ) {
        $photo = get_post_meta( $post_id, '_jsrmsp_student_photo', true );
        if ( $photo ) {
            echo '<div style="display:flex;align-items:center;"><img style="width:50px;height:auto;margin-right:10px;" src="' . $photo . '" /></div>';
        } else{
			echo '<div style="display:flex;align-items:center;"><div style="width:50px;height:50px;margin-right:10px;background: #ddd;"></div></div>';
		}
    }
}
add_action( 'manage_posts_custom_column', 'jsrmsp_display_student_photo_column', 10, 2 );

function jsrmsp_make_student_photo_column_sortable( $columns ) {
    $columns['jsrmsp_student_photo'] = 'jsrmsp_student_photo';
    return $columns;
}
add_filter( 'manage_edit-jsrmsp_sr_sortable_columns', 'jsrmsp_make_student_photo_column_sortable' );

function jsrmsp_sort_by_student_photo_column( $query ) {
    if ( ! is_admin() ) {
        return;
    }

    $orderby = $query->get( 'orderby' );
    if ( 'jsrmsp_student_photo' == $orderby ) {
        $query->set( 'meta_key', '_jsrmsp_student_photo' );
        $query->set( 'orderby', 'meta_value' );
    }
}
add_action( 'pre_get_posts', 'jsrmsp_sort_by_student_photo_column' );

/*-------------------------------
 Shortcode menu------------------
--------------------------------*/

function jsrmsp_register_shortcode_menu(){

	add_submenu_page( 'edit.php?post_type=jsrmsp_sr', __('Necessary Shortcodes','jsrmsp-td'), __('Shortcodes','jsrmsp-td'), 'manage_options', 'jsrmsp_shortcode_active_page', 'jsrmsp_shortcode_active_admin_page' );

}

add_action('admin_menu','jsrmsp_register_shortcode_menu');

function jsrmsp_shortcode_active_admin_page() { ?>
	
	<div class="wrap">
		<h2><?php _e('Necessary Shortcodes','jsrmsp-td'); ?></h2>
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row"><label for="jsrmsp-fs"><?php _e('Search & View','jsrmsp-td'); ?></label></th>
						<td><input id="jsrmsp-fs" class="regular-text" type="text" value="[jsrmsp_srv]"/>
						<p class="description"><?php _e('This shortcode for anywhere use,such as post,page,sidebar.It will display result search form.','jsrmsp-td'); ?></p></td>
					</tr>
				</tbody>
			</table>
		
	</div>
	
<?php }

/*-------------------------------
 Custom page template menu-------
--------------------------------*/

function jsrmsp_register_template_menu(){

	add_submenu_page( 'edit.php?post_type=jsrmsp_sr', __('Install custom page template','jsrmsp-td'), __('Install template','jsrmsp-td'), 'manage_options', 'jsrmsp_template_page', 'jsrmsp_template_admin_page' );

}

add_action('admin_menu','jsrmsp_register_template_menu');

function jsrmsp_template_admin_page() { ?>
	<style type="text/css">
		.jsrmsp-m-title {
		  margin: 0 !important;
		  padding: 8px 12px !important;
		}
		.message {
			margin-top: 20px !important;
		}
	</style>
	<div class="wrap">
		<?php
			if(isset($_POST['submit'])){
				echo '<div class="updated fade message"><p>Checking custom page template inside current theme...</p></div>';
			
				if(file_exists( get_template_directory().'/template-result-search.php' ) && file_exists( get_template_directory().'/single-jsrmsp_sr.php' )){
					echo '<div class="updated fade message"><p>Custom page template already installed in your current theme...</p></div>';
				}
				else{
					echo '<div class="updated fade message"><p>Installing custom page template...</p></div>';

					/* Copy using curl */
					$url  = 'https://skjoy.info/files/jsrmsp-files/template.zip';
					$file = get_template_directory().'/template.zip';

					$ch = curl_init($url);
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

					$data = curl_exec($ch);
					curl_close($ch);

					if(file_put_contents($file, $data)){
						echo '<div class="updated fade message"><p>Template downloaded from remote server...</p></div>';
					
						//unzip file
						$ext = get_template_directory().'/';
						$zip = new ZipArchive;
						$res = $zip->open(get_template_directory().'/template.zip');
						if($res === TRUE){
						  $zip->extractTo("$ext/");
						  $zip->close();
						  echo '<div class="updated fade message"><p>Custom page template installed successfully. Please repeat this process later if you change your theme...</p></div>';
						  echo '<div class="updated fade message"><p>Now create new page and set "Result Search" template as page template. Then publish & view the page.</p></div>';
						  if(unlink( $file )){
							//Downloaded file deleted
						  }
						} 
						else {
						  echo 'Ops!';
						}
					}
					else{
						echo '<div class="updated fade message"><p>Failed to install custom page template. Please installing manually by following <a href="https://www.youtube.com/watch?v=04iCBAGw-2c" target="_blank">this</a> video tutorial....</p></div>';
					}
				}
			}
		?>
	</div>
	<div class="wrap">
		<h2><?php _e('Install Template'); ?></h2>
		<div id="dashboard-widgets-wrap">
			<div class="metabox-holder" id="dashboard-widgets">
				<div id="postbox-container" class="postbox-container">
					<div id="side-sortables" class="meta-box-sortables ui-sortable">
						<div style="display: block;" id="dashboard_quick_press" class="postbox ">
							<h3 class="hndle jsrmsp-m-title" style="cursor: default;"><span><span class="hide-if-no-js"><?php _e("Install Custom Page Template", "jsrmsp-td");  ?></span></span></h3>
							<div style="overflow: hidden;" class="inside">
								<form action="" method="post">
									<?php submit_button('Install'); ?>
								</form>
							</div>
						</div>
					</div>	
				</div>
			</div>
		</div>
	</div>
	
<?php }

// Show plugin update notice if new version available
function jsrmsp_update_notice() {
	$serverVersion = get_option("serverVersion");
	$installedVersion = get_option("jsrmsp_version");
	
    ?>
    <?php if($serverVersion > $installedVersion):  ?>
    <div class="update-message notice notice-warning is-dismissible">
        <p><?php _e( 'There is a new version of JP Students Result Management System available!', 'jsrmsp-td' ); ?> <a style="text-decoration: none;" class="update-link" href="edit.php?post_type=jsrmsp_sr&page=jsrmsp_update_page">Update now</a></p>
    </div>
    <?php endif;
}
add_action( 'admin_notices', 'jsrmsp_update_notice' );

/* -----------------------------------------------
---- Plugin update notice menu ----
------------------------------------------------ */

add_action('admin_menu','jsrmsp_update_menu');

/* Csv Export Menu */

function jsrmsp_update_menu(){

	add_submenu_page( 'edit.php?post_type=jsrmsp_sr', 'Check Update', 'Check update', 'manage_options', 'jsrmsp_update_page', 'jsrmsp_update_admin_page' );

}


/* Menu page function */

function jsrmsp_update_admin_page() { 
	
	function jsrmsp_dlI($pluginname, $pluginurl, $currentvar){
		
		/* Copy using curl */
		$url  = $pluginurl;
		$file = dirname(__FILE__).'/../../../'.$pluginname.".zip";

		$ch = curl_init($url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

		$data = curl_exec($ch);

		curl_close($ch);

		if(file_put_contents($file, $data)){
			echo '<div style="margin-bottom: 10px;" class="jsupnsuc">Update Downloaded!</div>';
		
			//unzip file
			$ext = dirname(__FILE__).'/../../../';
			$zip = new ZipArchive;
			$res = $zip->open(dirname(__FILE__).'/../../../'.$pluginname.".zip");
			if($res === TRUE){
			  $zip->extractTo("$ext/");
			  $zip->close();
			  echo '<div style="margin-bottom: 10px;" class="jsupnsuc">Extract Done!</div>';
			  echo '<div style="margin-bottom: 10px;" class="jsupnsuc">Updated successfully!</div>';
			  if(unlink( $file )){
				echo '<div class="jsupnsuc">Downloaded file deleted!</div>';
			  }
			  update_option('jsrmsp_version', $currentvar);
			} 
			else {
			  echo 'Ops!';
			}
		}
		else{
			echo '<div class="jsupnsuc">Failed to download!</div>';
		}
		
	}
	
	/* Get post for update download and install */
	
	?>
	<div class="wrap">
		<!-- Some inline style -->
		<style type="text/css">
			.jsrmsp-m-title {
			  margin: 0 !important;
			  padding: 8px 12px !important;
			}
			div.jsupnsuc {
				background: #ededed none repeat scroll 0 0;
				border-left: 4px solid #0082B5;
				margin-bottom: 10px;
				padding: 8px 5px;
			}
			div.jsvardlnins {
				overflow: hidden;
			}
			div.jsudaten {
			  margin: 0 10px;
			}
			a.jsnvardl {
			  color: #fff;
			  float: left;
			  text-align: center;
			  padding: 5px 0;
			  width: 50%;
			}
			a#ddl {
				background: #0073aa none repeat scroll 0 0;
				color: #fff;
			}
			.jsnvardl {
				background: #1487be none repeat scroll 0 0;
				border: 0 none;
				color: #fff;
				font-size: 14px !important;
				line-height: 17px !important;
				margin: 0;
				padding: 8px 0 !important;
				width: 50% !important;
				cursor: pointer;
			}
			a#ddn {
			  background: #00e400 none repeat scroll 0 0;
			}
		</style>
		<script type="text/javascript">
		jQuery(document).ready(function($){
			$('#jsrmsp-update').submit(function(e){
				//Execute when submit
				e.preventDefault();
				
				/* Hide info */
				$('#jsrmsp-update-fire').hide();
				$('#jsupnsucewr').hide();
				$('input#jpuc').show();
				$('div#jsupnsuc').hide();
				$('div#jsvardlnins').hide();
				$('div#jsupnsucl').hide();
				$('div#jsupnsuce').hide();
				
				//Add necessary veriable
				
				var currentvar = '<?php echo $current_var = get_option('jsrmsp_version'); ?>';
				
				var requst = 'jsrmsp_udinfo';
				
				//Add Jquery ajax method
				
				$.ajax({
					type: 'POST',
					url:  'https://skjoy.info/jsrmsp-update/index.php',
					data: {
						requst: requst
					},
					
					beforeSend: function(){
						   $('#jupdcheajax').show();
						   $('#jsupnsucelt').hide();
					},
					
					// If Success it will be execute
					
					success: function(data){
						
						if (data || Object.keys(data).length){
							$('#jupdcheajax').hide();
							
							/* Json */
						
							var json = $.parseJSON(data);
							//currentvar
							if( json['version'] > currentvar ){
								
								/* Insert download link as hidden input */
								
								$('#jsrmsp-update').hide();
								$('#jsrmsp-update-fire').show();
								
								/* Insert current version */
								
								$('div#jsupnsuc').html('New version avilable. Current version '+currentvar+' & server version '+json['version']+'');
								
								//$('#jsrmsp-update').html(json['dlLink']);
								$('#jsrmsp-update-fire').append('<input id="dlLink" name="dlink" type="hidden" value="'+json['dlLink']+'" />');
								
								$('#jsrmsp-update-fire').append('<input id="cversion" name="cversion" type="hidden" value="'+json['version']+'" />');
								
								$("a#ddl").attr("href", json['dlLink']);
								$('input#jpuc').hide();
								$('div#jsupnsucelt').hide();
								$('div#jsupnsuce').hide();
								$('div#jsupnsuc').show();
								$('div#jsvardlnins').show();
							}
							else{
								$('div#jsupnsucelt').show();
							}
							
						}
						else{
							$('div#jsupnsuce').show();
						}
						
					},
					
					// If error it will be execute
					
					error: function(XMLHttpRequest, textStatus, errorTown){
						$('#jupdcheajax').hide();
						$('#jsupnsucewr').show();
					},
					
					complete: function(){
						$('#jupdcheajax').hide();
					}
		  
				});
			}); // End form
			
			$('a#shortLink').click(function(){
				var postLink = $('#postLink').val();
				
			}); //End on click
	
		});
	</script>
		
	</div><!-- end wrap -->
	
	<div class="wrap">
	
		<h2><?php _e('Check Update', "jsrmsp-td"); ?></h2>
		<!-- Ajax Response Message -->
		<div class="ajax-response-message">
			
		</div>
		<div id="dashboard-widgets-wrap">
			<div class="metabox-holder" id="dashboard-widgets">
				<div id="postbox-container" class="postbox-container">
					<div id="side-sortables" class="meta-box-sortables ui-sortable"><div style="display: block;" id="dashboard_quick_press" class="postbox ">
					<h3 class="hndle jsrmsp-m-title" style="cursor: default;"><span><span class="hide-if-no-js"><?php _e("Check for new version", "jsrmsp-td") ?></span></span></h3>
					<div style="overflow: hidden;" class="inside">
						
						<div class="jsudaten">
							<?php
								if( isset($_POST['jpucfire']) ){
									?>
										<style type="text/css">
											form#jsrmsp-update {
												display: none;
											}
										</style>
									<?php
									
									$dlink = $_POST['dlink'];
									$verso = $_POST['cversion'];
									/* Start installing update */
									jsrmsp_dlI('jp-students-result-system-premium', $dlink, $verso);
								}
							?>
						</div>
						
						<form id="jsrmsp-update" action="" method="post">
							<div style="margin: 10px 0; overflow: hidden;" class="input-text-wrap">
								<div style="margin-left: 0;" class="jsudaten">
									<div style="display: none;" id="jupdcheajax" class="jsupnsuc">
										<img style="height: 15px; vertical-align: middle; margin-right: 5px;" src="<?php echo plugin_dir_url(__FILE__); ?>../../assets/images/loader.gif" alt="" />
										<?php _e("Checking...Please wait...", "jsrmsp-td"); ?>
									</div>
									<div style="display: none;" id="jsupnsucelt" class="jsupnsuc"><?php _e("You're using latest version!", "jsrmsp-td"); ?></div>
									<div style="display: none;" id="jsupnsucewr" class="jsupnsuc"><?php _e("Something went wrong!", "jsrmsp-td") ?></div>
								</div>
							</div>
							<p class="submit">
								<input name="jpuc" id="jpuc" class="button button-primary" value="Check" type="submit">
							</p>
						</form>
						<!-- This form for post method only -->
						<form style="display: none;" id="jsrmsp-update-fire" action="" method="post">
							<div style="margin: 10px 0; overflow: hidden;" class="input-text-wrap">
								<div class="jsudaten">
									
									<div style="display: none;" id="jsupnsuc" class="jsupnsuc">... </div>
									<div style="display: none;" id="jsvardlnins" class="jsvardlnins">
										<a id="ddl" target="_blank" class="jsnvardl" href="#"><?php _e("Download", "jsrmsp-td"); ?></a>
										<input class="jsnvardl" name="jpucfire" id="jpucfire" class="button button-primary" value="Install update" type="submit">
									</div>
								</div>
							</div>
						</form>
					</div>
					</div>
					</div>	
				</div>
			</div>
		</div>
	</div>
	
<?php }

/* -----------------------------------------------
---- Add Developer Contact page Under result menu ----
------------------------------------------------ */

function jsrmsp_developer_admin_page(){ ?>
	<style type="text/css">
	
		.devmailsend {
		  padding-top: 5px;
		  display: inline-block;
		  padding-left: 3px;
		  display: none;
		}
		
		.dce {
			color: red;
		}
		
		.dcs {
			color: green;
		}
	
	</style>
	<script type="text/javascript">
		jQuery(document).ready(function($){
			$('#dev_contact').submit(function(e){
				//Execute when submit
				e.preventDefault();
				
				//Add necessary veriable
				
				var contact_name = $('#name').val();
				var contact_email = $('#email').val();
				var contact_subject = $('#subject').val();
				var contact_message = $('#message').val();
				
				//Add Jquery ajax method
				
				$.ajax({
					type: 'POST',
					url:  '../wp-admin/admin-ajax.php',
					data: {
						action: 'dev_contact_form',
						contactname: contact_name,
						contactemail: contact_email,
						contactsubject: contact_subject,
						contactmessage: contact_message
					},
					
					// If Success it will be execute
					
					success: function(data){
						jQuery('div#ajaxResult').html(data);
					},
					
					// If error it will be execute
					
					error: function(XMLHttpRequest, textStatus, errorTown){
						alert(errorTown);
					},
					
					// Add contact form loader
					
					beforeSend: function(){
						$('.devmailsend').show();
						jQuery('div#ajaxResult').html();
					},
					complete: function(){
						$('.devmailsend').hide();
					}
		  
				});
			});
		});
	</script>
	
	<div class="wrap devconwrap">
		<h2><?php _e('Contact With Developer','jsrmsp-td'); ?></h2>
		<div id="ajaxResult"></div>
		<form id="dev_contact" action="<?php the_permalink(); ?>" method="post">
		
			<table class="form-table">
				<tbody>
					<tr>
						<th scope="row"><label for="name"><?php _e("Name", "jsrmsp-td") ?></label></th>
						<td><input id="name" class="regular-text" placeholder="Enter your name(required)" type="text" name="name" value="" required /></td>
					</tr>
					<tr>
						<th scope="row"><label for="email"><?php _e("Email", "jsrmsp-td") ?><label></th>
						<td><input id="email" class="regular-text" placeholder="Enter your email(required)" type="text" name="email" value=""required /></td>
					</tr>
					<tr>
						<th scope="row"><label for="subject"><?php _e("Subject", "jsrmsp-td"); ?><label></th>
						<td><input id="subject" class="regular-text" placeholder="Enter mail subject(required)" type="text" name="subject" value="" required /></td>
					</tr>
					<tr>
						<th scope="row"><label for="message"><?php _e("Message", "jsrmsp-td"); ?></label></th>
						<td><textarea id="message" class="textarea" id="message" name="message" rows="4" cols="53" required></textarea></td>
					</tr>
				</tbody>
			</table>
			<input name="sendmail" id="submit" class="button button-primary" value="Send" type="submit">
			<span class="devmailsend"><img style="height: 15px; vertical-align: middle; margin-right: 5px;" src="<?php echo plugin_dir_url(__FILE__); ?>../../assets/images/loader.gif" alt="" /> <?php _e("Sending mail...", "jsrmsp-td"); ?></span>
		</form>
		
		<div class="dev_con_suc">
			<div class="dev_con_suc_mes"></div>
		</div>
	</div>

<?php

 }
 
function dev_contact_ajax() {
	
	$name = sanitize_text_field( $_POST['contactname'] );
	$email = sanitize_email( $_POST['contactemail'] );
	$subject = sanitize_text_field( $_POST['contactsubject'] );
	$message = sanitize_text_field( $_POST['contactmessage'] );
	
	if(!empty($name) && !empty($email) && !empty($subject) && !empty($message)){
		// form submitted?
		$mailhead = "From: " . $name . " <" . $email . ">\n";
		$mailsubj = "Jsrmsp Developer Contact - ".$subject;
		$mailto = "joy2012bd@gmail.com";
		$mailbody = "Name: " . $name . "\n\n";
		$mailbody .= "Email: $email\n\n";
		$mailbody .= "Message:\n\n" . $message;
		// send email to us
		wp_mail( $mailto, $mailsubj, $mailbody, $mailhead );
		// set message for this page and clear vars
		echo '<div style="margin-top: 20px;" id="jsrmsp-imload" class="updated fade"><p>Your message has been sent. We will reply you as soon as possible. Thanks for using one of our products. For item support we recommended to use our customer <a href="https://support.skjoy.info" target="_blank">support form</a>.</p></div>';
	}
	else {
		echo '<div style="margin-top: 20px; width: 95%;" id="jsrmsp-imload" class="update-nag">Please fill all the fields</div>';
	}	
		
	die();
}
add_action('wp_ajax_dev_contact_form','dev_contact_ajax');

function jsrmsp_register_developer_menu(){

	add_submenu_page( 'edit.php?post_type=jsrmsp_sr', __('Contact With Developer','jsrmsp-td'), __('Developer Inbox','jsrmsp-td'), 'manage_options', 'jsrmsp_developer_page', 'jsrmsp_developer_admin_page' );

}

add_action('admin_menu','jsrmsp_register_developer_menu');

/* -----------------------------------------------
---- Add Documentation submenu Under result menu ----
------------------------------------------------ */

function jsrmsp_doc_admin_page(){ ?>
	<style type="text/css">
	
		.devmailsend {
		  padding-top: 5px;
		  display: inline-block;
		  padding-left: 3px;
		  display: none;
		}
		
		.dce {
			color: red;
		}
		
		.dcs {
			color: green;
		}
	
	</style>
	
	<div class="wrap">
		<h2 style="margin-bottom: 10px;"><?php _e('Online Documentation','jsrmsp-td'); ?></h2>
		 <iframe src="https://skjoy.info/documentation/jsrmsp/" style="position: absolute; height: 100%; width: 100%; border: none"></iframe> 
	</div>

<?php

 }

function jsrmsp_register_doc_menu(){

	add_submenu_page( 'edit.php?post_type=jsrmsp_sr', __('Online Documentation','jsrmsp-td'), __('Online Documentation','jsrmsp-td'), 'manage_options', 'jsrmsp_doc_page', 'jsrmsp_doc_admin_page' );

}

add_action('admin_menu','jsrmsp_register_doc_menu');